%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%  EN_Calibrate.m
%%%%  Calibrate the productivity parameter in a network economy   
%%%%  with endogenous network creation
%%%%
%%%%  
%%%%  March 20, 2019
%%%%%%%%%%%%%%%%%%%%%%%%%%

%%Inputs

%1. N: the number of industries
%2. initial_alpha: the  cost_based input-output matrix
%3. initial_beta: consumption shares by industry
%4. markups: markups by industry
%5. real_gdp: the level of gdp being targeted


%Output: mu, the distribution parameter for b_{i0} and b_{ij}



function mu =  EN_Calibrate(N,initial_alpha,initial_beta,markups,real_gdp)

%%Create an anonymous function around EN_Simulate_Wrapper
my_fun = @(x) (EN_Simulate_Wrapper(x,real_gdp,N,initial_alpha,initial_beta,markups));

%% Use non-linear least squares to calibrate
[x,fval,exitflag,output] = fmincon(my_fun,0.5*log(real_gdp),0.25*log(real_gdp),0.75*log(real_gdp));
%%Output the parameter mu
mu = x(1);
end