%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%  ProcessData.m
%%%%  Ensure that the different data sources are coherent 
%%%%  
%%%%
%%%%  
%%%%  May 12, 2019
%%%%%%%%%%%%%%%%%%%%%%%%%%


function [revenue_io,labor_share,gdp_shares,N,CommodityNames,IndustryNames,ValueAdded,Consumption]=ProcessData(CommodityNames,IndustryNames,InputOutput,ValueAdded,Consumption);

%%Obtain commodity and industry names as strings
CommodityNames = string(CommodityNames);
IndustryNames = string(IndustryNames');


%First commodity name is column title. Remove it
CommodityNames(1) = [];

%% Remove government sector industries
CommodityNames = CommodityNames(1:393);
IndustryNames = IndustryNames(1:394);
ValueAdded = ValueAdded(1:394);
Consumption = Consumption(1:394);

%% Find commodities that don't correspond to industries and 
%% industries that don't correspond to commodities.
%% Remove them to ensure that the input-output matrix is square
x = setdiff(CommodityNames,IndustryNames);
y = setdiff(IndustryNames,CommodityNames);
idx = find(IndustryNames == y);
InputOutput(:,idx) = [];
ValueAdded(idx) = [];
IndustryNames(idx) = [];
Consumption(idx) = [];


%Remove customs duties and owner-occupied housing, which have a labor share
%of 0. 
labor_share = InputOutput(406,1:393);
custom_duties = InputOutput(282,1:393);
indices = find(labor_share == 0 );
InputOutput(indices,:) = [];
InputOutput(:,indices) = [];
labor_share(indices) = [];
ValueAdded(indices) = [];
display(CommodityNames(indices));
CommodityNames(indices) = [];
IndustryNames(indices) = [];
custom_duties(indices) = [];
Consumption(indices) = [];

%%Compute the number of industries
N = length(CommodityNames);

%%Obtain the input-output matrix
revenue_io = InputOutput(1:N,1:N);
revenue_io = revenue_io';

%Transpose the labor share
labor_share = labor_share';

%Compute consumption shares
gdp_shares = Consumption(1:N);
gdp_shares = gdp_shares ./sum(gdp_shares);

end

