"""
writeTables.py

September 3rd 2018
Pablo Azar

This script collects data from individual tables written by Stata (for coefficients and standard errors) and Matlab
(for counterfactuals) and collates them into a big table (called big_table_tfp.tex)

Some extra LaTex cleaning is required to create big_table_final.tex because Stata sometimes mangles
the names of the variables so they don't compile well in LaTex.

This script also creates the Appendix tables

"""

##Initialize the table
outfile_name = "../../Tables/big_table_tfp.tex"
outfile = file(outfile_name,'w')
outfile.write("\\begin{tabular}{lccc} \hline \n & (1) & (2) & (3) \\\\  \n")

#3 Panels, one for each filter (all industries, manufacturing, or no computers)
filters=["all","manuf","computer"]
filter_names = {'all':'Panel A: All Industries (1987-2007) ','manuf':'Panel B: Manufacturing(1987-2007)','no_manuf':'No Manufacturing','computer':' Panel C: All Industries Excluding Computers (1987-2007)'}

#What is the right hand variable for this table
righthands = ["dummy_20"]

#Legacy: name the standard error
standard_error_names=["cluster sic_group"]


#For each panel...
for filter in filters:
    #Write the panel header
    outfile.write( "\hline  \multicolumn{4}{c}{"+filter_names[filter]+"} \\\\ \\hline \n" )
    
    #For each regressor (usually only one in the final tables)
    for righthand in righthands:
        #Get the counterfactuals
        counterfactuals_file = file("../../ProcessedData/CSV/Counterfactuals_"+filter+"_"+righthand+"_1_.csv",'r')
        counterfactual_lines = counterfactuals_file.readlines()
        counterfactuals = counterfactual_lines[0].strip().split(',')
        counterfactuals = map(float,counterfactuals)
        counterfactuals = map(lambda x:  "{0:.2f}\\%".format(100*x),counterfactuals)
        counterfactuals = '&'.join(counterfactuals)
        #Get the coefficients and standard errors
        infile_name = "../../Tables/final_"+filter+"_"+righthand+".tex"
        infile = file(infile_name,'r')
        lines = infile.readlines()
        coeffs = lines[4].replace(',','')
        standard_errors = lines[5]
       
        #Write coefficients, standard errors and counterfactuals
        outfile.write(coeffs)
        outfile.write(standard_errors)
        outfile.write('Counterfactual TFP Change &' + counterfactuals + ' \\\\ \n')
        infile.close()

##Finalize the table
outfile.flush()
outfile.write(" \\\\ \hline Linear Industry Trends &  No & Yes &  Yes  \\\\ \n ")
outfile.write(" \\\\ \hline Control for lagged change in TFP  &  No  & No  &  Yes   \\\\ \n ")
outfile.write(" \end{tabular}\n")
outfile.close()


outfile_name = "../../Tables/big_table_tfp_weighted.tex"
outfile = file(outfile_name,'w')
outfile.write("\\begin{tabular}{lccc} \hline \n & (1) & (2) & (3) \\\\  \n")

filters=["all","manuf","computer"]
filter_names = {'all':'Panel A: All Industries (1987-2007) ','manuf':'Panel B: Manufacturing(1987-2007)','no_manuf':'No Manufacturing','computer':' Panel C: All Industries Excluding Computers (1987-2007)'}
righthands = ["dummy_20"]
standard_error_names=["cluster sic_group"]


counter = 0
for filter in filters:
    outfile.write( "\hline  \multicolumn{4}{c}{"+filter_names[filter]+"} \\\\ \\hline \n" )
    

    for righthand in righthands:
        counterfactuals_file = file("../../ProcessedData/CSV/Counterfactuals_"+filter+"_"+righthand+"_1_weighted.csv",'r')
        counterfactual_lines = counterfactuals_file.readlines()
        infile_name = "../../Tables/final_"+filter+"_"+righthand+"_weighted.tex"
        infile = file(infile_name,'r')
        lines = infile.readlines()
        
        coeffs = lines[4].replace(',','')
        standard_errors = lines[5]
        counterfactuals = counterfactual_lines[0].strip().split(',')
        counterfactuals = map(float,counterfactuals)
        counterfactuals = map(lambda x:  "{0:.2f}\\%".format(100*x),counterfactuals)
        counterfactuals = '&'.join(counterfactuals)
        outfile.write(coeffs)
        
        outfile.write(standard_errors)
        outfile.write('Counterfactual TFP Change &' + counterfactuals + ' \\\\ \n')
        infile.close()

outfile.flush()
outfile.write(" \\\\ \hline Linear Industry Trends &  No & Yes &  Yes  \\\\ \n ")
outfile.write(" \\\\ \hline Control for lagged change in TFP  &  No  & No  &  Yes   \\\\ \n ")
outfile.write(" \end{tabular}\n")
outfile.close()

filter_names = {'all':'Panel A: All Industries (1997-2007) ','manuf':'Panel B: Manufacturing (1997-2007)','no_manuf':'No Manufacturing','computer':' Panel C: All Industries Excluding Computers (1997-2007)'}

outfile_name = "../../Tables/big_table_tfp_1997.tex"
outfile = file(outfile_name,'w')
outfile.write("\\begin{tabular}{lccc} \hline \n & (1) & (2) & (3) \\\\  \n")

for filter in filters:
    outfile.write( "\hline  \multicolumn{4}{c}{"+filter_names[filter]+"} \\\\ \\hline \n" )
    for righthand in righthands:
        infile_name = "../../Tables/final_"+filter+"_"+righthand+"_1997.tex"
        infile = file(infile_name,'r')
        lines = infile.readlines()
        counterfactuals_file = file("../../ProcessedData/CSV/Counterfactuals_"+filter+"_"+righthand+"_2_.csv",'r')
        counterfactual_lines = counterfactuals_file.readlines()
        coeffs = lines[4].replace(',','')
        standard_errors = lines[5]     
        counterfactuals = counterfactual_lines[0].strip().split(',')
        counterfactuals = map(float,counterfactuals)
        counterfactuals = map(lambda x:  "{0:.2f}\\%".format(100*x),counterfactuals)
        counterfactuals = '&'.join(counterfactuals)
        outfile.write(coeffs)
        outfile.write(standard_errors)
        outfile.write('Counterfactual TFP Change &' + counterfactuals + '\\\\ \n')

        infile.close()

outfile.flush()

outfile.write(" \\\\ \hline Linear Industry Trends &  No & Yes &  Yes  \\\\ \n ")
outfile.write(" \\\\ \hline Control for lagged change in TFP  &  No  & No  &  Yes   \\\\ \n ")
outfile.write(" \end{tabular}\n")
outfile.close()

outfile_name = "../../Tables/big_table_tfp_30.tex"
outfile = file(outfile_name,'w')
outfile.write("\\begin{tabular}{lccc} \hline \n & (1) & (2) & (3)  \\\\  \n")

filters=["all","manuf","computer"]
filter_names = {'all':'Panel A: All Industries (1987-2007) ','manuf':'Panel B: Manufacturing(1987-2007)','no_manuf':'No Manufacturing','computer':' Panel C: All Industries Excluding Computers (1987-2007)'}
righthands = ["dummy_30"]
standard_error_names=["cluster sic_group"]


counter = 0
for filter in filters:
    outfile.write( "\hline  \multicolumn{4}{c}{"+filter_names[filter]+"} \\\\ \\hline \n" )
    

    for righthand in righthands:
        counterfactuals_file = file("../../ProcessedData/CSV/Counterfactuals_"+filter+"_"+righthand+"_1_.csv",'r')
        counterfactual_lines = counterfactuals_file.readlines()
        infile_name = "../../Tables/final_"+filter+"_"+righthand+".tex"
        infile = file(infile_name,'r')
        lines = infile.readlines()
        
        coeffs = lines[4].replace(',','')
        standard_errors = lines[5]
        counterfactuals = counterfactual_lines[0].strip().split(',')
        counterfactuals = map(float,counterfactuals)
        counterfactuals = map(lambda x:  "{0:.2f}\\%".format(100*x),counterfactuals)
        counterfactuals = '&'.join(counterfactuals)
        outfile.write(coeffs)
        
        outfile.write(standard_errors)
        outfile.write('Counterfactual TFP Change &' + counterfactuals + ' \\\\ \n')
        infile.close()

outfile.flush()


outfile.write(" \\\\ \hline Linear Industry Trends &  No & Yes &  Yes  \\\\ \n ")
outfile.write(" \\\\ \hline Control for lagged change in TFP  &  No  & No    \\\\ \n ")
outfile.write(" \end{tabular}\n")
outfile.close()

outfile_name = "../../Tables/big_table_tfp_10.tex"
outfile = file(outfile_name,'w')
outfile.write("\\begin{tabular}{lccc} \hline \n & (1) & (2) & (3)   \\\\  \n")

filters=["all","manuf","computer"]
filter_names = {'all':'Panel A: All Industries (1987-2007) ','manuf':'Panel B: Manufacturing(1987-2007)','no_manuf':'No Manufacturing','computer':' Panel C: All Industries Excluding Computers (1987-2007)'}
righthands = ["dummy_10"]
standard_error_names=["cluster sic_group"]


counter = 0
for filter in filters:
    outfile.write( "\hline  \multicolumn{4}{c}{"+filter_names[filter]+"} \\\\ \\hline \n" )
    

    for righthand in righthands:
        counterfactuals_file = file("../../ProcessedData/CSV/Counterfactuals_"+filter+"_"+righthand+"_1_.csv",'r')
        counterfactual_lines = counterfactuals_file.readlines()
        infile_name = "../../Tables/final_"+filter+"_"+righthand+".tex"
        infile = file(infile_name,'r')
        lines = infile.readlines()
        
        coeffs = lines[4].replace(',','')
        standard_errors = lines[5]
        counterfactuals = counterfactual_lines[0].strip().split(',')
        counterfactuals = map(float,counterfactuals)
        counterfactuals = map(lambda x:  "{0:.2f}\\%".format(100*x),counterfactuals)
        counterfactuals = '&'.join(counterfactuals)
        outfile.write(coeffs)
        
        outfile.write(standard_errors)
        outfile.write('Counterfactual TFP Change &' + counterfactuals + ' \\\\ \n')
        infile.close()

outfile.flush()


outfile.write(" \\\\ \hline Linear Industry Trends &  No & Yes &  Yes \\\\ \n ")
outfile.write(" \\\\ \hline Control for lagged change in TFP  &  No  & No  &  Yes   \\\\ \n ")
outfile.write(" \end{tabular}\n")
outfile.close()

