//ProcessAggregatedIndustries.do

/*

Read the excel file that has MFP and Labor Productivity for Aggregated Industries

Save it in a format that is compatible with the NBER CES database


*/
 use  "../../ProcessedData/Stata/SetDifferencesAndIndegrees",clear
 rename sic sic_down
 replace sic_down = strtrim(lower(sic_down))
 
 joinby sic_down  using "../../Data/SICIndustriesToBEAAggregates.dta",unmatched(master)
 replace sic_down = beacode_down  if _merge == 3
 bysort sic_down year: egen mean_indegree = mean(indegree) if _merge == 3
 bysort sic_down year: egen mean_jaccard= mean(jaccard) if _merge == 3

 
 replace indegree = mean_indegree if _merge == 3
 replace jaccard = mean_jaccard if _merge == 3

 duplicates drop beacode_down year  if _merge == 3,force 
 drop _merge
 drop beacode_down
 drop sic_up
 drop beacode_up

save "../../ProcessedData/Stata/SetDifferencesAndIndegrees3",replace


/****************************************************
STEP 2: Read MFP By BEA Industry (From BEA BLS industry level production accounts)
******************************************************/


 import excel "../../Data/BEA-BLS-industry-level-production-account-1987-1998.xlsx", sheet("Integrated MFP Index") cellrange(A2:AE68) firstrow clear
 local year = 1987
 foreach var_name of varlist  B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE{
	rename `var_name' MFP`year'
	local year = `year' + 1
 
 }
 
 reshape long MFP, i(IndustryDescription) j(year)
 keep if MFP != .
 egen ind_group = group(IndustryDescription)
 xtset ind_group year
 gen smooth_MFP = (F1.MFP + MFP+ L1.MFP) / 3
 keep if mod(year,5)==2
 keep if year != 2012
  
 
 rename IndustryDescription sic_down
 replace sic_down = lower(sic_down)
 
 distinct sic_down
 save  "../../ProcessedData/Stata/MFP",replace
 
 /****************************************************
STEP 3: Read Output By BEA Industry (From BEA BLS industry level production accounts)
******************************************************/
 
  import excel "../../Data/BEA-BLS-industry-level-production-account-1987-1998.xlsx", sheet("Gross Output") cellrange(A2:AE65) firstrow clear
 local year = 1987
 foreach var_name of varlist  B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE{
	rename `var_name' Output`year'
	local year = `year' + 1
 
 }
 
 reshape long Output, i(IndustryDescription) j(year)
 keep if Output != .
 keep if mod(year,5)==2
 keep if year != 2012
  
 
 rename IndustryDescription sic_down
 replace sic_down = lower(sic_down)
 distinct sic_down
 merge 1:1 year sic_down using "../../ProcessedData/Stata/MFP"
 assert _merge == 3
 drop _merge
 distinct sic_down
 save  "../../ProcessedData/Stata/MFP",replace
 
  /****************************************************
STEP 3.b: Read Output Quantity Indices By BEA Industry (From BEA BLS industry level production accounts)
******************************************************/
 
  import excel "../../Data/BEA-BLS-industry-level-production-account-1987-1998.xlsx", sheet("Gross Output_Quantity") cellrange(A2:AE65) firstrow clear
 local year = 1987
 foreach var_name of varlist  B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE{
	rename `var_name' OutputQuantity`year'
	local year = `year' + 1
 
 }
 
 reshape long OutputQuantity, i(IndustryDescription) j(year)
 keep if Output != .
 keep if mod(year,5)==2
 keep if year != 2012
  
 
 rename IndustryDescription sic_down
 replace sic_down = lower(sic_down)
 distinct sic_down
 merge 1:1 year sic_down using "../../ProcessedData/Stata/MFP"
 assert _merge == 3
 drop _merge
 distinct sic_down
 
 gen price_index = Output/OutputQuantity
  gen price_index_1987=price_index if year==1987
 egen price_base = max(price_index_1987),by(sic_down)
 replace price_index = price_index/price_base
 
 
 save  "../../ProcessedData/Stata/MFP",replace
 
  /****************************************************
STEP 4: Read Value Added By BEA Industry (From BEA BLS industry level production accounts)
******************************************************/
 
  import excel "../../Data/BEA-BLS-industry-level-production-account-1987-1998.xlsx", sheet("Value Added") cellrange(A2:AE65) firstrow clear
 local year = 1987
 foreach var_name of varlist  B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE{
	rename `var_name' ValueAdded`year'
	local year = `year' + 1
 
 }
 
 reshape long ValueAdded, i(IndustryDescription) j(year)
 keep if ValueAdded != .
 keep if mod(year,5)==2
 keep if year != 2012
  
 
 rename IndustryDescription sic_down
 replace sic_down = lower(sic_down)
 distinct sic_down
 merge 1:1 year sic_down using "../../ProcessedData/Stata/MFP"
 assert _merge == 3
 drop _merge
 distinct sic_down
 save  "../../ProcessedData/Stata/MFP",replace
 
 
  
  /****************************************************
STEP 5: Read Labor Productivity By BEA Industry (From BEA BLS industry level production accounts)
******************************************************/
 
 
  import excel "../../Data/BEA-BLS-industry-level-production-account-1987-1998.xlsx", sheet("Integrated Labor Productivity") cellrange(A2:AE68) firstrow clear
 local year = 1987
 foreach var_name of varlist  B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE{
	rename `var_name' LaborProductivity`year'
	local year = `year' + 1
 
 }
 
 reshape long LaborProductivity, i(IndustryDescription) j(year)
 keep if LaborProductivity != .
 keep if mod(year,5)==2
 keep if year != 2012
  
 
 rename IndustryDescription sic_down
 replace sic_down = lower(sic_down)
 
 merge 1:1 year sic_down using "../../ProcessedData/Stata/MFP"
 assert _merge == 3
 drop _merge
 distinct sic_down
 save  "../../ProcessedData/Stata/MFP",replace
 
 
   
  /****************************************************
STEP 6: Read Labor Hour Indices By BEA Industry (From BEA BLS industry level production accounts)
*************************/
 
  import excel "../../Data/BEA-BLS-industry-level-production-account-1987-1998.xlsx", sheet("Labor Hours_Quantity") cellrange(A2:AE65) firstrow clear
 local year = 1987
 foreach var_name of varlist  B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE{
	rename `var_name' LaborHours`year'
	local year = `year' + 1
 
 }
 
 reshape long LaborHours, i(IndustryDescription) j(year)
 keep if LaborHours != .
 keep if mod(year,5)==2
 keep if year != 2012
  
 
 rename IndustryDescription sic_down
 replace sic_down = lower(sic_down)
 
 merge 1:1 year sic_down using "../../ProcessedData/Stata/MFP"
 assert _merge == 3
 drop _merge
 distinct sic_down
 save  "../../ProcessedData/Stata/MFP",replace
 
 
 
   /****************************************************
STEP 8: Merge with NBER-CES data
*************************/
 use  "../../ProcessedData/Stata/MFP",clear

 rename sic_down sic
 merge 1:1 sic year using "../../Data/sic5811"
 
 rename sic sic_down

 drop _merge
 egen sic_group = group(sic_down)
 xtset sic_group year
 
 gen smooth_tfp = (L.tfp5 + tfp5 + F.tfp5)/3
  
 replace smooth_tfp = smooth_MFP if tfp5 == .
 replace tfp5 = MFP if tfp5 == .
 replace vadd = ValueAdded if vadd == .
 replace vship = Output if vship == .
 replace emp = LaborHours if emp == .
 replace LaborProductivity = vadd/(piship*prodh) if LaborProductivity == .
 replace piship = price_index if piship == .
 
 gen tfp1987=tfp5 if year==1987
 gen LaborProductivity1987 = LaborProductivity if year==1987
 egen tfp_index = max(tfp1987),by(sic_group)
 egen labor_index = max(LaborProductivity1987),by(sic_group)
 replace LaborProductivity = LaborProductivity/labor_index
 replace tfp5 = tfp5/tfp_index
 
  gen smooth_tfp1992=smooth_tfp if year==1992
 egen smooth_tfp_index = max(smooth_tfp1992),by(sic_group)
 replace smooth_tfp = smooth_tfp/smooth_tfp_index
  
 
 replace tfp5 = log(tfp5)
 replace smooth_tfp = log(smooth_tfp)
 gen delta_smooth_tfp = D.smooth_tfp
 replace LaborProductivity = log(LaborProductivity)
 bysort year: egen mean_tfp = mean(tfp5)
  bysort year: egen mean_labor_productivity = mean(LaborProductivity)
xtset sic_group year



 replace sic_down = lower(sic_down)
 xtset sic_group year
 keep if mod(year,5)==2
 keep if year>=1987
 keep if year<= 2007
   bysort sic_group (year): gen t = _n
 xtset sic_group t
 gen log_output = log(vship)
 gen log_value_added = log(vadd)
 gen delta_tfp = D.tfp5
 gen delta_piship = D.piship
 gen delta_labor_productivity = D.LaborProductivity
 gen delta_output = D.log_output
 gen delta_value_added = D.log_value_added
 
 
 


   merge 1:1 sic_down year using "../../ProcessedData/Stata/SetDifferencesAndIndegrees3"
  keep if _merge == 3 | year ==1987
  bysort sic_group: gen num_obs = _N
  keep if num_obs==5
 drop _merge
 xtset sic_group t
  gen delta_indegree = D.indegree


 
  destring sic_down, force gen(sic_num)
 gen all = 1
 gen industry_group = floor(sic_num/10)
 gen manuf = (string(sic_num)==sic_down)
 gen computer = (industry_group!=357 & industry_group!=367)
  save "../../ProcessedData/Stata/sicMFP_2",replace
 export delimited using "../../ProcessedData/CSV/SIC_Data.csv", replace

 merge m:1 sic_down using "../../Data/sic-codes"
 keep if _merge !=2
 replace description = sic_down if description == ""

  
 
  

 
 
egen total_vadd = total(vadd),by(year)
gen vadd_weight = vadd/total_vadd
bysort sic_group (year): gen vadd_weight_2 = vadd_weight[1]
replace vadd_weight = vadd_weight_2
 save "../../ProcessedData/Stata/sicMFP_3",replace
 
 

set more off

xtset sic_group t
gen materials_cost = matcos / pimat
gen investment_cost = invest / piinv
gen energy_cost = energy / pien
gen  delta_pimat = D.pimat
gen delta_piinv = D.piinv
gen delta_pien  = D.pien


set more off
gen no_manuf = manuf == 0
set more off


bysort year: egen jaccard_20 = pctile(jaccard),p(20)
bysort year: egen jaccard_10 = pctile(jaccard),p(10)
bysort year: egen jaccard_30 = pctile(jaccard),p(30)
gen dummy_20  =  (jaccard >=jaccard_20 )
gen dummy_10  =  (jaccard >=jaccard_10 )
gen dummy_30  = (jaccard >=jaccard_30 )

save "../../ProcessedData/Stata/MergedDataset",replace


